# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainui.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets
import resource

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(774, 774)
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(12)
        MainWindow.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/png/icon/Nuitka.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setGeometry(QtCore.QRect(20, 90, 731, 141))
        self.groupBox.setObjectName("groupBox")
        self.checkBox = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox.setGeometry(QtCore.QRect(20, 40, 151, 17))
        self.checkBox.setObjectName("checkBox")
        self.checkBox_2 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_2.setGeometry(QtCore.QRect(200, 100, 111, 21))
        self.checkBox_2.setObjectName("checkBox_2")
        self.checkBox_3 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_3.setGeometry(QtCore.QRect(200, 40, 141, 17))
        self.checkBox_3.setObjectName("checkBox_3")
        self.checkBox_4 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_4.setGeometry(QtCore.QRect(200, 70, 141, 17))
        self.checkBox_4.setObjectName("checkBox_4")
        self.checkBox_5 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_5.setGeometry(QtCore.QRect(330, 40, 151, 21))
        self.checkBox_5.setObjectName("checkBox_5")
        self.checkBox_6 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_6.setGeometry(QtCore.QRect(330, 70, 151, 17))
        self.checkBox_6.setObjectName("checkBox_6")
        self.checkBox_7 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_7.setGeometry(QtCore.QRect(20, 100, 91, 17))
        self.checkBox_7.setObjectName("checkBox_7")
        self.checkBox_8 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_8.setGeometry(QtCore.QRect(20, 70, 171, 17))
        self.checkBox_8.setObjectName("checkBox_8")
        self.checkBox_10 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_10.setGeometry(QtCore.QRect(330, 100, 101, 21))
        self.checkBox_10.setObjectName("checkBox_10")
        self.checkBox_9 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_9.setGeometry(QtCore.QRect(500, 40, 221, 21))
        self.checkBox_9.setObjectName("checkBox_9")
        self.checkBox_17 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_17.setGeometry(QtCore.QRect(500, 70, 211, 17))
        self.checkBox_17.setObjectName("checkBox_17")
        self.checkBox_20 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_20.setGeometry(QtCore.QRect(500, 100, 211, 17))
        self.checkBox_20.setObjectName("checkBox_20")
        self.groupBox_2 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_2.setGeometry(QtCore.QRect(20, 410, 731, 241))
        self.groupBox_2.setObjectName("groupBox_2")
        self.label_3 = QtWidgets.QLabel(self.groupBox_2)
        self.label_3.setGeometry(QtCore.QRect(20, 30, 171, 21))
        self.label_3.setObjectName("label_3")
        self.lineEdit_3 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_3.setGeometry(QtCore.QRect(200, 30, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_3.setFont(font)
        self.lineEdit_3.setObjectName("lineEdit_3")
        self.pushButton_3 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_3.setGeometry(QtCore.QRect(550, 30, 75, 23))
        self.pushButton_3.setObjectName("pushButton_3")
        self.pushButton_10 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_10.setGeometry(QtCore.QRect(640, 30, 75, 23))
        self.pushButton_10.setObjectName("pushButton_10")
        self.label_5 = QtWidgets.QLabel(self.groupBox_2)
        self.label_5.setGeometry(QtCore.QRect(20, 150, 271, 21))
        self.label_5.setObjectName("label_5")
        self.lineEdit_4 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_4.setGeometry(QtCore.QRect(200, 60, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_4.setFont(font)
        self.lineEdit_4.setObjectName("lineEdit_4")
        self.pushButton_4 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_4.setGeometry(QtCore.QRect(550, 60, 75, 23))
        self.pushButton_4.setObjectName("pushButton_4")
        self.pushButton_12 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_12.setGeometry(QtCore.QRect(640, 60, 75, 23))
        self.pushButton_12.setObjectName("pushButton_12")
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setGeometry(QtCore.QRect(20, 90, 271, 21))
        self.label_6.setObjectName("label_6")
        self.lineEdit_5 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_5.setEnabled(False)
        self.lineEdit_5.setGeometry(QtCore.QRect(200, 90, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_5.setFont(font)
        self.lineEdit_5.setObjectName("lineEdit_5")
        self.pushButton_5 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_5.setGeometry(QtCore.QRect(550, 90, 75, 23))
        self.pushButton_5.setObjectName("pushButton_5")
        self.pushButton_14 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_14.setGeometry(QtCore.QRect(640, 90, 75, 23))
        self.pushButton_14.setObjectName("pushButton_14")
        self.label_7 = QtWidgets.QLabel(self.groupBox_2)
        self.label_7.setGeometry(QtCore.QRect(20, 120, 151, 21))
        self.label_7.setObjectName("label_7")
        self.lineEdit_8 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_8.setEnabled(False)
        self.lineEdit_8.setGeometry(QtCore.QRect(200, 120, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_8.setFont(font)
        self.lineEdit_8.setObjectName("lineEdit_8")
        self.pushButton_15 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_15.setGeometry(QtCore.QRect(550, 120, 75, 23))
        self.pushButton_15.setObjectName("pushButton_15")
        self.pushButton_16 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_16.setGeometry(QtCore.QRect(640, 120, 75, 23))
        self.pushButton_16.setObjectName("pushButton_16")
        self.label_8 = QtWidgets.QLabel(self.groupBox_2)
        self.label_8.setGeometry(QtCore.QRect(20, 60, 171, 21))
        self.label_8.setObjectName("label_8")
        self.lineEdit_9 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_9.setGeometry(QtCore.QRect(200, 150, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_9.setFont(font)
        self.lineEdit_9.setObjectName("lineEdit_9")
        self.pushButton_17 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_17.setGeometry(QtCore.QRect(640, 150, 75, 23))
        self.pushButton_17.setObjectName("pushButton_17")
        self.pushButton_18 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_18.setGeometry(QtCore.QRect(550, 150, 75, 23))
        self.pushButton_18.setObjectName("pushButton_18")
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setGeometry(QtCore.QRect(20, 180, 61, 21))
        self.label_4.setObjectName("label_4")
        self.lineEdit_6 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_6.setGeometry(QtCore.QRect(200, 180, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_6.setFont(font)
        self.lineEdit_6.setObjectName("lineEdit_6")
        self.pushButton_19 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_19.setGeometry(QtCore.QRect(640, 180, 75, 23))
        self.pushButton_19.setObjectName("pushButton_19")
        self.pushButton_20 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_20.setGeometry(QtCore.QRect(550, 180, 75, 23))
        self.pushButton_20.setObjectName("pushButton_20")
        self.radioButton = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton.setGeometry(QtCore.QRect(200, 210, 89, 17))
        self.radioButton.setObjectName("radioButton")
        self.radioButton_2 = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton_2.setGeometry(QtCore.QRect(360, 210, 101, 17))
        self.radioButton_2.setObjectName("radioButton_2")
        self.pushButton_7 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_7.setGeometry(QtCore.QRect(140, 680, 131, 31))
        self.pushButton_7.setObjectName("pushButton_7")
        self.pushButton_8 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_8.setGeometry(QtCore.QRect(340, 680, 101, 31))
        self.pushButton_8.setObjectName("pushButton_8")
        self.pushButton_9 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_9.setGeometry(QtCore.QRect(500, 680, 101, 31))
        self.pushButton_9.setObjectName("pushButton_9")
        self.layoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 10, 721, 33))
        self.layoutWidget.setObjectName("layoutWidget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.layoutWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(self.layoutWidget)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.lineEdit = QtWidgets.QLineEdit(self.layoutWidget)
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout.addWidget(self.lineEdit)
        self.pushButton = QtWidgets.QPushButton(self.layoutWidget)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        self.layoutWidget1 = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget1.setGeometry(QtCore.QRect(21, 50, 721, 33))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.lineEdit_2 = QtWidgets.QLineEdit(self.layoutWidget1)
        self.lineEdit_2.setObjectName("lineEdit_2")
        self.horizontalLayout_2.addWidget(self.lineEdit_2)
        self.pushButton_2 = QtWidgets.QPushButton(self.layoutWidget1)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_2.addWidget(self.pushButton_2)
        self.groupBox_3 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_3.setGeometry(QtCore.QRect(20, 240, 731, 161))
        self.groupBox_3.setObjectName("groupBox_3")
        self.checkBox_11 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_11.setGeometry(QtCore.QRect(20, 30, 231, 21))
        self.checkBox_11.setObjectName("checkBox_11")
        self.checkBox_13 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_13.setGeometry(QtCore.QRect(260, 30, 201, 21))
        self.checkBox_13.setObjectName("checkBox_13")
        self.checkBox_15 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_15.setGeometry(QtCore.QRect(500, 30, 211, 21))
        self.checkBox_15.setObjectName("checkBox_15")
        self.checkBox_12 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_12.setGeometry(QtCore.QRect(20, 60, 221, 21))
        self.checkBox_12.setObjectName("checkBox_12")
        self.checkBox_18 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_18.setGeometry(QtCore.QRect(260, 60, 201, 21))
        self.checkBox_18.setObjectName("checkBox_18")
        self.checkBox_19 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_19.setGeometry(QtCore.QRect(20, 90, 231, 21))
        self.checkBox_19.setObjectName("checkBox_19")
        self.checkBox_22 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_22.setGeometry(QtCore.QRect(500, 60, 201, 21))
        self.checkBox_22.setObjectName("checkBox_22")
        self.checkBox_23 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_23.setGeometry(QtCore.QRect(20, 120, 201, 21))
        self.checkBox_23.setObjectName("checkBox_23")
        self.checkBox_24 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_24.setGeometry(QtCore.QRect(500, 90, 211, 21))
        self.checkBox_24.setObjectName("checkBox_24")
        self.checkBox_25 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_25.setGeometry(QtCore.QRect(260, 90, 241, 21))
        self.checkBox_25.setObjectName("checkBox_25")
        self.checkBox_14 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_14.setGeometry(QtCore.QRect(260, 120, 281, 21))
        self.checkBox_14.setObjectName("checkBox_14")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 774, 27))
        self.menubar.setObjectName("menubar")
        self.menu = QtWidgets.QMenu(self.menubar)
        self.menu.setObjectName("menu")
        self.menu_2 = QtWidgets.QMenu(self.menubar)
        self.menu_2.setObjectName("menu_2")
        self.menu_3 = QtWidgets.QMenu(self.menubar)
        self.menu_3.setObjectName("menu_3")
        self.menu_4 = QtWidgets.QMenu(self.menubar)
        self.menu_4.setObjectName("menu_4")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(8)
        self.statusbar.setFont(font)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menubar.addAction(self.menu.menuAction())
        self.menubar.addAction(self.menu_2.menuAction())
        self.menubar.addAction(self.menu_3.menuAction())
        self.menubar.addAction(self.menu_4.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "EasyNuitka"))
        self.groupBox.setTitle(_translate("MainWindow", "package method"))
        self.checkBox.setText(_translate("MainWindow", "--follow-imports"))
        self.checkBox_2.setText(_translate("MainWindow", "--mingw64"))
        self.checkBox_3.setText(_translate("MainWindow", "--standalone"))
        self.checkBox_4.setText(_translate("MainWindow", "--onefile"))
        self.checkBox_5.setText(_translate("MainWindow", "--show-memory"))
        self.checkBox_6.setText(_translate("MainWindow", "--show-progress"))
        self.checkBox_7.setText(_translate("MainWindow", "--module "))
        self.checkBox_8.setText(_translate("MainWindow", "--nofollow-imports"))
        self.checkBox_10.setText(_translate("MainWindow", "--msvc64"))
        self.checkBox_9.setText(_translate("MainWindow", "--include-plugin-pyqt5"))
        self.checkBox_17.setText(_translate("MainWindow", "--include-plugin-numpy"))
        self.checkBox_20.setText(_translate("MainWindow", "--include-plugin-torch"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Parameter Setting"))
        self.label_3.setText(_translate("MainWindow", "--nofollow-import-to"))
        self.lineEdit_3.setText(_translate("MainWindow", "Enter module/package ;Separate them with commas"))
        self.pushButton_3.setText(_translate("MainWindow", "Add"))
        self.pushButton_10.setText(_translate("MainWindow", "Remove"))
        self.label_5.setText(_translate("MainWindow", "--include-package"))
        self.lineEdit_4.setText(_translate("MainWindow", "Select the folder you want to compile"))
        self.pushButton_4.setText(_translate("MainWindow", "Add"))
        self.pushButton_12.setText(_translate("MainWindow", "Remove"))
        self.label_6.setText(_translate("MainWindow", "--include-data-files"))
        self.pushButton_5.setText(_translate("MainWindow", "Add"))
        self.pushButton_14.setText(_translate("MainWindow", "Remove"))
        self.label_7.setText(_translate("MainWindow", "--include-data-dir"))
        self.pushButton_15.setText(_translate("MainWindow", "Add"))
        self.pushButton_16.setText(_translate("MainWindow", "Remove"))
        self.label_8.setText(_translate("MainWindow", "--follow-import-to"))
        self.lineEdit_9.setText(_translate("MainWindow", "Default to the entire module"))
        self.pushButton_17.setText(_translate("MainWindow", "Remove"))
        self.pushButton_18.setText(_translate("MainWindow", "Add"))
        self.label_4.setText(_translate("MainWindow", "  Icons"))
        self.lineEdit_6.setText(_translate("MainWindow", "Select  icon"))
        self.pushButton_19.setText(_translate("MainWindow", "Remove"))
        self.pushButton_20.setText(_translate("MainWindow", "Add"))
        self.radioButton.setText(_translate("MainWindow", "windows"))
        self.radioButton_2.setText(_translate("MainWindow", "console"))
        self.pushButton_7.setText(_translate("MainWindow", "Start package"))
        self.pushButton_8.setText(_translate("MainWindow", "Stop"))
        self.pushButton_9.setText(_translate("MainWindow", "Quite"))
        self.label.setText(_translate("MainWindow", "Main File/Module"))
        self.pushButton.setText(_translate("MainWindow", "choose"))
        self.label_2.setText(_translate("MainWindow", "OutPut Path          "))
        self.pushButton_2.setText(_translate("MainWindow", "choose"))
        self.groupBox_3.setTitle(_translate("MainWindow", "other plugin"))
        self.checkBox_11.setText(_translate("MainWindow", "--include-plugin-matplotlib"))
        self.checkBox_13.setText(_translate("MainWindow", "--include-plugin-pyqt6"))
        self.checkBox_15.setText(_translate("MainWindow", "--include-plugin-pyside2"))
        self.checkBox_12.setText(_translate("MainWindow", "--include-plugin-pyside6"))
        self.checkBox_18.setText(_translate("MainWindow", "--include-plugin-no-qt5"))
        self.checkBox_19.setText(_translate("MainWindow", "--include-plugin-tensorflow"))
        self.checkBox_22.setText(_translate("MainWindow", "--include-plugin-upx"))
        self.checkBox_23.setText(_translate("MainWindow", "--include-plugin-trio"))
        self.checkBox_24.setText(_translate("MainWindow", "--include-plugin-tk-inter"))
        self.checkBox_25.setText(_translate("MainWindow", "--include-plugin-pywebview"))
        self.checkBox_14.setText(_translate("MainWindow", "--include-plugin-multiprocessing"))
        self.menu.setTitle(_translate("MainWindow", "File"))
        self.menu_2.setTitle(_translate("MainWindow", "Edit"))
        self.menu_3.setTitle(_translate("MainWindow", "Setting"))
        self.menu_4.setTitle(_translate("MainWindow", "Help"))

